@@ -1,8 +1,9 @@
 
 from .load import load
+from pytplot import options
 
 def mfi(trange=['2018-11-5', '2018-11-6'],
-        datatype='k0',
+        datatype='h3',
         suffix='',  
         get_support_data=False, 
         varformat=None,
@@ -14,7 +15,8 @@ def mfi(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Fluxgate Magnetometer
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -22,6 +24,13 @@ def mfi(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h0: 16-Second Level 2 Data
+                h1: 4-Minute Level 2 Data
+                h2: 1-Hour Level 2 Data
+                h3: (default) 1-Second Level 2 Data
+                k0: 5-Minute Key Parameters [PRELIM]
+                k1: 16-Second Key Parameters [PRELIM]
+                k2: 1-Hour Key Parameters [PRELIM] 
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -53,14 +62,28 @@ def mfi(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
-    return load(instrument='fgm', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    tvars = load(instrument='fgm', trange=trange, datatype=datatype, suffix=suffix, get_support_data=get_support_data, varformat=varformat, varnames=varnames, downloadonly=downloadonly, notplot=notplot, time_clip=time_clip, no_update=no_update)
+    
+    if tvars is None or notplot or downloadonly:
+        return tvars
+
+    if 'Magnitude'+suffix in tvars:
+        options('Magnitude'+suffix, 'ytitle', 'ACE MFI')
+        options('Magnitude'+suffix, 'legend_names',  'Magnitude')
+
+    if 'BGSEc'+suffix in tvars:
+        options('BGSEc'+suffix, 'ytitle', 'ACE MFI')
+        options('BGSEc'+suffix, 'legend_names',  ['Bx', 'By', 'Bz'])
+
+    return tvars
 
 def swe(trange=['2018-11-5', '2018-11-6'],
-        datatype='k0',
+        datatype='h0',
         suffix='',  
         get_support_data=False, 
         varformat=None,
@@ -72,7 +95,8 @@ def swe(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Solar Wind Electron, Proton and Alpha Monitor (SWEPAM)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -80,6 +104,10 @@ def swe(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h0: (default) 64-Second Level 2 Data
+                h2: 1-Hour Level 2 Data
+                k0: 5-Minute Key Parameters [PRELIM] 
+                k1: 1-Hour Key Parameters [PRELIM]
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -111,7 +139,8 @@ def swe(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -130,7 +159,8 @@ def epam(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Electron Proton Alpha Monitor (EPAM)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -138,6 +168,11 @@ def epam(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h1: 5-Minute Level 2 Data
+                h2: 1-Hour Level 2 Data
+                h3: 12-second Level 2 Data
+                k0: (default) 5-Minute Key Parameters
+                k1: 1-Hour Key Parameters
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -169,7 +204,8 @@ def epam(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -188,7 +224,8 @@ def cris(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Cosmic Ray Isotope Spectrometer (CRIS)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -196,6 +233,8 @@ def cris(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h2: (default) 1-Hour Level 2 Data
+                h3: Daily-averaged Level 2 Data
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -227,7 +266,8 @@ def cris(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -246,7 +286,8 @@ def sis(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Solar Isotope Spectrometer (SIS)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -254,6 +295,9 @@ def sis(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h1: (default) 256-sec Level 2 Data
+                h2: 1-Hour Level 2 Data
+                k0: 1-Hour Key Parameters
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -285,7 +329,8 @@ def sis(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -305,7 +350,8 @@ def uleis(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Ultra Low Energy Isotope Spectrometer (ULEIS)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -313,6 +359,7 @@ def uleis(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h2: 1-Hour Level 2 Data
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -344,7 +391,8 @@ def uleis(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -364,7 +412,8 @@ def sepica(trange=['2004-11-5', '2004-11-6'],
     """
     This function loads data from the Solar Energetic Particle Ionic Charge Analyzer (SEPICA)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -372,6 +421,7 @@ def sepica(trange=['2004-11-5', '2004-11-6'],
 
         datatype: str
             Data type; Valid options:
+                h2: 1-Hour Level 2 Data
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -403,7 +453,8 @@ def sepica(trange=['2004-11-5', '2004-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
@@ -422,7 +473,8 @@ def swics(trange=['2018-11-5', '2018-11-6'],
     """
     This function loads data from the Solar Wind Ion Composition Spectrometer (SWICS)
     
-    Parameters:
+    Parameters
+    ----------
         trange : list of str
             time range of interest [starttime, endtime] with the format 
             'YYYY-MM-DD','YYYY-MM-DD'] or to specify more or less than a day 
@@ -430,6 +482,12 @@ def swics(trange=['2018-11-5', '2018-11-6'],
 
         datatype: str
             Data type; Valid options:
+                sw2_h3: (default) SWICS 2.0 Solar Wind 2-Hour Level 2 Data
+                swi_h2: SWICS 1.1 Solar Wind 1-Hour Level 2 Data
+                swi_h3: SWICS 1.1 Solar Wind 2-Hour Level 2 Data
+                swi_h4: SWICS 1.1 Solar Wind 1-Day Level 2 Data 
+                swi_h5: SWICS 1.1 Solar Wind 2-Hour Level 2 Q-state distributions 
+                swi_h6: Solar Wind Protons 12-min Level 2 Data
 
         suffix: str
             The tplot variable names will be given this suffix.  By default, 
@@ -461,7 +519,8 @@ def swics(trange=['2018-11-5', '2018-11-6'],
         time_clip: bool
             Time clip the variables to exactly the range specified in the trange keyword
 
-    Returns:
+    Returns
+    ----------
         List of tplot variables created.
 
     """
