@@ -4,6 +4,7 @@ import unittest
 from pyspedas.utilities.data_exists import data_exists
 from pyspedas.mms.fpi.mms_fpi_split_tensor import mms_fpi_split_tensor
 
+
 class FPITestCases(unittest.TestCase):
     def test_split_tensors(self):
         data = pyspedas.mms.fpi(trange=['2015-10-16/13:06', '2015-10-16/13:07'],
@@ -24,4 +25,8 @@ class FPITestCases(unittest.TestCase):
         output = ['mms1_des_temptensor_gse_brst_' + component for component in components]
 
         for v in output:
-            self.assertTrue(data_exists(v))
\ No newline at end of file
+            self.assertTrue(data_exists(v))
+
+
+if __name__ == '__main__':
+    unittest.main()
